// Graphing sketch

// This program takes ASCII-encoded strings
// from the serial port at 9600 baud and graphs them. It expects values in the
// range 0 to 1023, followed by a newline, or newline and carriage return

// Created 20 Apr 2005
// Updated 18 Jan 2008
// by Tom Igoe
// This example code is in the public domain.


// használjuk a beépített soros kommunikációs könyvtárat 
import processing.serial.*; 
Serial myPort;        // nevezzük a soros portunkat myPortnak
int xPos = 1;         // a grafikonunk aktuális vízszintes koordinátája

void setup () { 
  size(400, 300);  // a képernyő mérete      
  println(Serial.list()); // nyomtassuk ki az összes elérhető portot

    // nyissuk meg a portot, ahogy az előző példában
  myPort = new Serial(this, Serial.list()[0], 9600);

  /* A serialEvent() funkciót fogjuk használni – ami nagyon hasonló pl. a mousePressed()-hez: akkor aktív, amikor egy előre definiált folyamat lezajlik. Itt nem az egér megnyomására, hanem egy soros porton beérkező vezérlőkarakterre fogunk várni. A két aposztróf közötti karakter (char) változóként megadott érték ‘\n’, decimálisan 10-ként is megadható (lásd ASCII tábla) a „New Line” vezérlőkarakter kódja. A bufferUntil addig gyűjti egy tárolóba a sorosan kapott byte-okat, amíg meg nem érkezik az a karakter, amire vár. Ebben a formában a soros portunk bejövő adatainak átmeneti tárolójába mindig egyetlen byte fog kerülni, hiszen az Arduino programunk minden adat után elküldi az „új sor” kódját is (println). /
   myPort.bufferUntil('\n');
   
   background(0); // fekete háttér
   }
   
   void draw () {
   // minden a serialEvent()-en belül fog történni
   }
   
   void serialEvent (Serial myPort) {
   
  /* az adatot string változóként olvassuk be, ami egy karaktereket tároló tömb. Az inString fogja tartalmazni az összes beolvasott karakterünket
   readStringUntil-el megadjuk a fent ismertetett szeparáló karaktert, minden „új sor”-ig olvassuk a portot */
  String inString = myPort.readStringUntil('\n');

  if (inString != null) {
    // ha a karakterláncunk nem üres, akkor vágjuk le a felesleges részeket
    inString = trim(inString);
    // alakítsuk át a beolvasott karaktert szám formátumúra
    float inByte = float(inString); 

    /* változó = map (változó, változó minimuma, változó maximuma, eredmény 
     minimuma, eredmény maximuma) ezzel a függvénnyel a beolvasott adat értékét a képernyő magasságával arányossá tesszük*/
    inByte = map(inByte, 0, 1023, 0, height);

    stroke(127, 34, 255);
    // az adat a képernyő magasságához mért vonalként jelenik meg
    line(xPos, height, xPos, height - inByte);

    // a képernyő szélére érve a rajzolás vízszintes pozícióját 
    // visszaállítjuk a képernyő elejére
    if (xPos >= width) {
      xPos = 0;
      background(0);
    } else {
      // növeljük a vízszintes pozíció értékét, 
      // amíg el nem érjük a képernyő szélét
      xPos++;
    }
  }
}

